import base64
import json
from django.http import JsonResponse, HttpResponse
from hhycommon import HHYAES


def hhy_net_response(code, msg, data={}, debug=0):
    ret_json = {
        'code': code,
        'msg': msg,
        'data': data
    }
    if debug:
        return JsonResponse(ret_json, safe=False)
    json_str = json.dumps(ret_json)
    aes_encrypt_data = HHYAES.aes_encrypt(json_str)
    ret = base64.b64encode(json.dumps(aes_encrypt_data).encode(encoding='utf-8'))
    return HttpResponse(ret)



from Crypto.Cipher import AES
import base64

from django.conf import settings


class Aes_ECB(object):
    def __init__(self, key):
        self.key = key
        self.MODE = AES.MODE_ECB
        self.BS = AES.block_size
        self.pad = lambda s: s + (self.BS - len(s) % self.BS) * chr(self.BS - len(s) % self.BS)
        self.unpad = lambda s: s[0:-ord(s[-1])]

    # str不是16的倍数那就补足为16的倍数
    def add_to_16(value):
        while len(value) % 16 != 0:
            value += '\0'
        return str.encode(value)  # 返回bytes

    def AES_encrypt(self, text):
        aes = AES.new(Aes_ECB.add_to_16(self.key), self.MODE)  # 初始化加密器
        encrypted_text = str(base64.encodebytes(aes.encrypt(Aes_ECB.add_to_16(self.pad(text)))),
                             encoding='utf-8').replace('\n', '')  # 这个replace大家可以先不用，然后在调试出来的结果中看是否有'\n'换行符
        # 执行加密并转码返回bytes
        return encrypted_text

    # 解密
    def AES_decrypt(self, text):
        # 初始化加密器
        aes = AES.new(Aes_ECB.add_to_16(self.key), self.MODE)
        # 优先逆向解密base64成bytes
        base64_decrypted = base64.decodebytes(text.encode(encoding='utf-8'))
        decrypted_text = self.unpad(aes.decrypt(base64_decrypted).decode('utf-8'))
        decrypted_code = decrypted_text.rstrip('\0')
        return decrypted_code


KEY = "20220128202201282022012820220128"

def getaeskey():
    if settings.AES_SECRET_KEY:
        return settings.AES_SECRET_KEY
    else:
        return KEY

def aes_encrypt(str):
    return Aes_ECB(key=getaeskey()).AES_encrypt(str)

def aes_decrypt(str):
    return Aes_ECB(key=getaeskey()).AES_decrypt(str)

# en = encrypt("hehe")
# print('encrypt:'+en)
# print('decrypt:'+decrypt(en))


import base64
import time
from hhycommon import HHYAES
 

class AuthCheck(object):

    # 解析用户token信息
    def parseToken(utoken):
        # base64解密
        utoken = str(base64.b64decode(utoken), 'utf-8')
        if not utoken:
            raise Exception('11008 空值错误')
        aes_decrypt_data = HHYAES.aes_decrypt(utoken)
        utoken_segs = aes_decrypt_data.split('>')
        if len(utoken_segs) < 1:
            raise Exception('解析token失败')

        return utoken_segs

    # 时间戳比60s大就有问题
    def checkToken(utoken):
        utoken_segs = AuthCheck.parseToken(utoken=utoken)
        uid = utoken_segs[0]
        if not uid:
            raise Exception('10098')
        timestmp = utoken_segs[1]
        if int(round(time.time() * 1000)) - int(timestmp) > 60:
            # print(int(round(time.time() * 1000)))
            # print(timestmp)
            raise Exception("t error")
        else:
            return (uid,timestmp)




import base64
import json

from django.conf import settings

from hhycommon import HHYAES
from hhycommon.NetResponse import hhy_net_response


class NetEncrypt(object):

    def process_request(request):
        # print('收到请求-------------------')
        if request.method == 'GET':
            # 解密之后验证解密数据
            params = request.GET.get("params")
            if not params:
                # 静态网页放过
                pass
            else:
                try:
                    params_bytes = base64.b64decode(params)
                    if not params_bytes or params_bytes == -1:
                        return hhy_net_response(603, "授权错误")

                    aes_decrypt_data = HHYAES.aes_decrypt(params_bytes.decode(encoding='utf-8'))
                    ret_json = json.loads(aes_decrypt_data)
                    if not ret_json or ret_json.get('hhid') != 'hehuoya':
                        return hhy_net_response(304, '系统异常', {})
                    request.ret_json = ret_json
                except Exception as e:
                    print(e)
                    return hhy_net_response(604, "异常失败")
        elif request.method == 'POST':
            body = request.body
            if request.path == '/githook/':
                pass
            elif not body:
                return hhy_net_response(602, request.path)
            else:
                try:
                    params_bytes = base64.b64decode(body)
                    if not params_bytes or params_bytes == -1:
                        return hhy_net_response(606, "授权错误")
                    aes_decrypt_data = HHYAES.aes_decrypt(params_bytes.decode(encoding='utf-8'))
                    ret_json = json.loads(aes_decrypt_data)
                    if not ret_json or ret_json.get('hhid') != 'hehuoya':
                        return hhy_net_response(304, '系统异常', {})
                    request.ret_json = ret_json
                except Exception as e:
                    print(e)
                    return hhy_net_response(607, e.__str__())
        else:
            return hhy_net_response(608, "异常失败")



from django.core.cache import cache


def baseN(num, b=31):
    return ((num == 0) and "0") or \
           (baseN(num // b, b).lstrip("0") + "23456789abcdefghjkmnpqrstuvwxyz"[num % b])


def getRecommendCode():
    # cache.delete('recommend_code')
    origin_num = cache.get('recommend_code', 21100300)
    print('recommend_code = %s' % origin_num)
    code = 'qwf8v'
    if (origin_num == 21100300):
        cache.set('recommend_code', origin_num + 1)
        print('code ', code)
    else:
        next_num = origin_num + 1
        code = baseN(next_num)
        cache.set('recommend_code', next_num)
    return code.upper()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
import os

version = "0.1.0.9"
with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding='utf-8') as readme:
    README = readme.read()

setuptools.setup(
    name="hhycommon",
    version=version,
    author="lichanghong",
    author_email="1211054926@qq.com",
    description="加密等专用模块.",
    long_description=README,
    license='BSD License',
    long_description_content_type="text/markdown",
    url="https://hehuoya.com",
    install_requires=[
        'Crypto'
    ],
    packages=setuptools.find_packages(exclude=("hhycommon")),
    classifiers=(
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5"
    )

)